@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-
+import sys
 import inspect
 
 try:
@@ -29,6 +29,13 @@ except ImportError:
 from .internal import ANY_ARG
 
 
+def get_func(func):
+    if sys.version_info >= (3, 4):
+        return func.__func__
+    else:
+        return func.im_func
+
+
 def create_proxy(collaborator):
     if collaborator is None:
         return DummyProxy()
@@ -59,7 +66,8 @@ class Proxy(object):
     def is_method_or_func(self, method_name):
         func = getattr(self.collaborator, method_name)
         if inspect.ismethod(func):
-            func = func.__func__
+            func = get_func(func)
+            # func = func.im_func
         return inspect.isfunction(func)
 
 
@@ -200,7 +208,8 @@ class MethodSignature(Signature):
             args = (None,) + args  # self
 
         retval = getcallargs(self.method, *args, **context.kargs)
-        del retval['self']
+        if 'self' in retval:
+            del retval['self']
         return retval
 
     def assure_matches(self, context):
